import requests
import urllib.parse
from .user import login, logout


class NeedLoginException(Exception):
    pass

class LoginExpireException(Exception):
    pass

class NetworkErrorException(Exception):
    pass

class FailResponseException(Exception):
    pass


class Http:
    jwt = ""
    
    def __init__(self):
        pass
    
    @classmethod
    def login(cls, username, password):
        cls.jwt = login(username=username, password=password)

    @classmethod
    def logout(cls):
        logout(cls.jwt)
        cls.jwt = ''


    def get(self, url, params):
        return self.request('{}?{}'.format(url, urllib.parse.urlencode(params)))


    def post(self, url, payload):
        return self.request(url, payload=payload)


    def request(self, url, payload=None):


        if not self.jwt:
            raise NeedLoginException("需要登陆。")

        headers = {
            'Authorization': 'jwt {}'.format(self.jwt),
        }

        if not payload:
            payload = {}

        req = requests.request("GET", url, headers=headers, data=payload)

        if req.status_code > 500:
            raise NetworkErrorException("网络错误：{}".format(req.status_code))

        if req.status_code == 401:
            raise LoginExpireException("登陆过期：{}".format(req.status_code))

        if req.status_code != 200:
            raise Exception("未知错误：{}".format(req.status_code))

        data = req.json()

        if data['status'] != 'SUCCESS':
            raise FailResponseException("返回失败：{} {}".format(data['status'], data.get("msg", "NONE MESSAGE.")))

        if 'data' in data: return data['data']
        
        if 'status' in data: del data['status']

        if 'msg' in data: del data['msg']

        if 'message' in data: del data['message']

        return data





import json
import requests
from .CONST import HOST


def login(username, password):

    url = "https://opendata.gubaike.com/api/user_manager/login"

    payload = {
        "login_type": "nor_pass",
        "username": username,
        "password": password,
    }
    headers = {
        'Content-Type': 'application/json'
    }

    response = requests.request(
        "POST", url, headers=headers, data=json.dumps(payload))

    data = response.json()

    if data['status'] == 'SUCCESS':
        jwt = response.json()['jwt']
    else:
        jwt = ''

    return jwt


def logout(jwt):
    pass



import os
from setuptools import setup


def _process_requirements():
    packages = open('requirements.txt').read().strip().split('\n')
    requires = []
    for pkg in packages:
        if pkg.startswith('git+ssh'):
            return_code = os.system('pip install {}'.format(pkg))
            assert return_code == 0, 'error, status_code is: {}, exit!'.format(
                return_code)
        else:
            requires.append(pkg)

    print(requires)
    return requires



def _process_readme():
    with open('README.rst', encoding='utf-8') as fp:
        return fp.read()
    return ''


setup(name='jdodata',
      version='1.0.15',
      description="Jianda Open Data",
      long_description=_process_readme(),
      classifiers=["Development Status :: 5 - Production/Stable",
                   "License :: OSI Approved :: Apache Software License",
                   "Programming Language :: Python :: 3",
                   "Programming Language :: Python :: 3.5",
                   "Programming Language :: Python :: 3.6",
                   "Programming Language :: Python :: 3.7",
                   "Programming Language :: Python :: 3.8",
                   "Programming Language :: Python :: 3.9",
                   "Programming Language :: Python :: 3.10",
                   "Topic :: Office/Business :: Financial"
                   ],
      keywords='简答数据,jianda,jianda data,open data',
      author='@wukehao',
      author_email='wukehao@jddatatech.com',
      license='MIT',
      packages=['jdodata', 'jdodata.utils'],
      include_package_data=True,
      package_data={},
      zip_safe=True,
      setup_requires=['requests'],
      install_requires=_process_requirements(),
      entry_points="")
